pilas.habilidades.Habilidad

Package pilas :: Module habilidades :: Class Habilidad |
[hide private]
[frames] | no frames]

# Class Habilidad

source code

    object --+
             |
            Habilidad

Known Subclasses:
  - Arrastrable
  - , AumentarConRueda
  - , RebotarComoPelota
  - , Disparar
  - , Imitar
  - , MirarAlActor
  - , MoverseConElTeclado
  - , PisaPlataformas
  - , PuedeExplotar
  - , RebotarComoCaja
  - , RotarConMouse
  - , SeMantieneEnPantalla
  - , SeguirAlMouse
  - , SeguirClicks
  - , SiempreEnElCentro

Representa una habilidad que un actor puede aprender.

Instance Methods | [hide private]
__init__(self, receptor) x.__init__(...) initializes x; see help(type(x)) for signature | source code
actualizar(self) | source code
eliminar(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)